@@ -1,6 +1,6 @@
 """Salus iT600 smart device models."""
 
-from typing import Any, List, NamedTuple
+from typing import List, NamedTuple
 
 
 class ClimateDevice(NamedTuple):
@@ -21,3 +21,12 @@ class ClimateDevice(NamedTuple):
     supported_features: int
     device_class: str
     data: dict
+
+
+class BinarySensorDevice(NamedTuple):
+    available: bool
+    name: str
+    unique_id: str
+    is_on: bool
+    device_class: str
+    data: dict
